@@ -99,6 +99,7 @@ c
 #endif
          save rm
 c                z component only, transvers direction not affected
+         p = q
          if(i .eq. 1) then
             tmp=gb.p(1)**2 + gb.p(2)**2
             agb.p(1) = 0.
@@ -107,9 +108,7 @@ c                z component only, transvers direction not affected
             agb.p(4) = gb.p(4)
          endif
          call clorez(agb, q, pt)
-         if(agb.p(3) .eq. 0.) then
-            p = q
-         else
+         if(agb.p(3) .ne. 0.) then
             if(i .eq. 1) then
 c                 matrix for y-axis
                if(tmp .eq. 0. .and. gb.p(3) .eq. 0.) then
@@ -131,7 +130,6 @@ c                 combined rotaion matrix
 c                 do rotaion
             call capplyRot4(rm, pt.fm.p,  p.fm.p)
             p.fm.p(4)=pt.fm.p(4)
-            p.mass = q.mass
          endif
       end
 
